Struct CartesianDiffusion2D

pub struct CartesianDiffusion2D<F> {
    pub domain: CartesianCuboid<F, 2>,
    pub reactions_dx: Vector2<F>,
    pub diffusion_constant: F,
    pub initial_value: DVector<F>,
}
Domain based on CartesianCuboid in 2 dimensions with extracellular diffusion.

We solve the equations

Fields

domain: CartesianCuboid<F, 2>reactions_dx: Vector2<F>

The discretization must be a multiple of the voxel size. This quantity will be used as an initial estimate and rounded to the nearest candidate.

diffusion_constant: F

Diffusion constant

initial_value: DVector<F>

Initial values which are uniform over the simulation domain