pub struct MiePotential {
pub radius: f64,
pub strength: f64,
pub bound: f64,
pub cutoff: f64,
pub en: f64,
pub em: f64,
}Expand description
Generalizeation of the BoundLennardJones potential.
\begin{align} U(r) &= C\epsilon\left[ \left(\frac{\sigma}{r}\right)^n - \left(\frac{\sigma}{r}\right)^m\right]\\ C &= \frac{n}{n-m}\left(\frac{n}{m}\right)^{\frac{n}{n-m}}\\ V(r) &= \min(U(r), \beta)\theta(r-\zeta) \end{align}
This struct comes in a 64bit version MiePotential and a 32bit variant MiePotentialF32.
References
G. Mie, “Zur kinetischen Theorie der einatomigen Körper,” Annalen der Physik, vol. 316, no. 8. Wiley, pp. 657–697, Jan. 1903. doi: 10.1002/andp.19033160802.
Fields
radius: f64Interaction strength $\epsilon$ of the potential.
strength: f64Overall size $\sigma$ of the object of the potential.
bound: f64Numerical bound $\beta$ of the interaction strength.
cutoff: f64Defines a cutoff $\zeta$ after which the potential will be fixed to exactly zero.
en: f64Exponent $n$ of the potential
em: f64Exponent $m$ of the potential
Implementations
Sourceimpl MiePotential
impl MiePotential
Sourcepub fn new(
radius: f64,
strength: f64,
bound: f64,
cutoff: f64,
en: f64,
em: f64,
) -> Self
Available on crate feature pyo3 only.
pub fn new( radius: f64, strength: f64, bound: f64, cutoff: f64, en: f64, em: f64, ) -> Self
pyo3 only.Constructs a new MiePotential
use cellular_raza_building_blocks::MiePotential;
let (radius, strength, bound, cutoff, en, em) = (1.0, 1.0, 1.0, 1.0, 1.0, 1.0);
let mie_potential = MiePotential::new(
radius,
strength,
bound,
cutoff,
en,
em,
);Trait Implementations
Sourceimpl AbsDiffEq for MiePotential
impl AbsDiffEq for MiePotential
Sourcefn default_epsilon() -> Self::Epsilon
fn default_epsilon() -> Self::Epsilon
Sourcefn abs_diff_eq(&self, other: &Self, epsilon: Self::Epsilon) -> bool
fn abs_diff_eq(&self, other: &Self, epsilon: Self::Epsilon) -> bool
fn abs_diff_ne(&self, other: &Rhs, epsilon: Self::Epsilon) -> bool
fn abs_diff_ne(&self, other: &Rhs, epsilon: Self::Epsilon) -> bool
AbsDiffEq::abs_diff_eq].Sourceimpl Clone for MiePotential
impl Clone for MiePotential
Sourcefn clone(&self) -> MiePotential
fn clone(&self) -> MiePotential
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for MiePotential
impl Debug for MiePotential
Sourceimpl<'de> Deserialize<'de> for MiePotential
impl<'de> Deserialize<'de> for MiePotential
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Sourceimpl<const D: usize> Interaction<Matrix<f64, Const<D>, Const<1>, ArrayStorage<f64, D, 1>>, Matrix<f64, Const<D>, Const<1>, ArrayStorage<f64, D, 1>>, Matrix<f64, Const<D>, Const<1>, ArrayStorage<f64, D, 1>>, f64> for MiePotential
impl<const D: usize> Interaction<Matrix<f64, Const<D>, Const<1>, ArrayStorage<f64, D, 1>>, Matrix<f64, Const<D>, Const<1>, ArrayStorage<f64, D, 1>>, Matrix<f64, Const<D>, Const<1>, ArrayStorage<f64, D, 1>>, f64> for MiePotential
Sourcefn calculate_force_between(
&self,
own_pos: &SVector<f64, D>,
_own_vel: &SVector<f64, D>,
ext_pos: &SVector<f64, D>,
_ext_vel: &SVector<f64, D>,
ext_radius: &f64,
) -> Result<(SVector<f64, D>, SVector<f64, D>), CalcError>
fn calculate_force_between( &self, own_pos: &SVector<f64, D>, _own_vel: &SVector<f64, D>, ext_pos: &SVector<f64, D>, _ext_vel: &SVector<f64, D>, ext_radius: &f64, ) -> Result<(SVector<f64, D>, SVector<f64, D>), CalcError>
fn is_neighbor(
&self,
own_pos: &Pos,
ext_pos: &Pos,
ext_inf: &Inf,
) -> Result<bool, CalcError>
fn is_neighbor( &self, own_pos: &Pos, ext_pos: &Pos, ext_inf: &Inf, ) -> Result<bool, CalcError>
fn react_to_neighbors(&mut self, neighbors: usize) -> Result<(), CalcError>
fn react_to_neighbors(&mut self, neighbors: usize) -> Result<(), CalcError>
Sourceimpl InteractionInformation<f64> for MiePotential
impl InteractionInformation<f64> for MiePotential
Sourcefn get_interaction_information(&self) -> f64
fn get_interaction_information(&self) -> f64
Sourceimpl<'py> IntoPyObject<'py> for MiePotential
impl<'py> IntoPyObject<'py> for MiePotential
Sourcetype Target = MiePotential
type Target = MiePotential
Sourcetype Output = Bound<'py, <MiePotential as IntoPyObject<'py>>::Target>
type Output = Bound<'py, <MiePotential as IntoPyObject<'py>>::Target>
Sourcefn into_pyobject(
self,
py: Python<'py>,
) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
fn into_pyobject( self, py: Python<'py>, ) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
Sourceimpl PartialEq for MiePotential
impl PartialEq for MiePotential
Sourceimpl PyClass for MiePotential
impl PyClass for MiePotential
Sourceimpl PyClassImpl for MiePotential
impl PyClassImpl for MiePotential
Sourceconst IS_BASETYPE: bool = false
const IS_BASETYPE: bool = false
Sourceconst IS_SUBCLASS: bool = false
const IS_SUBCLASS: bool = false
Sourceconst IS_MAPPING: bool = false
const IS_MAPPING: bool = false
Sourceconst IS_SEQUENCE: bool = false
const IS_SEQUENCE: bool = false
Sourceconst IS_IMMUTABLE_TYPE: bool = false
const IS_IMMUTABLE_TYPE: bool = false
Sourceconst RAW_DOC: &'static CStr = c"Generalizeation of the [BoundLennardJones] potential.\n\n\\\\begin{align}\n U(r) &= C\\epsilon\\left[ \\left(\\frac{\\sigma}{r}\\right)^n -\n \\left(\\frac{\\sigma}{r}\\right)^m\\right]\\\\\\\\\n C &= \\frac{n}{n-m}\\left(\\frac{n}{m}\\right)^{\\frac{n}{n-m}}\\\\\\\\\n V(r) &= \\min(U(r), \\beta)\\theta(r-\\zeta)\n\\\\end{align}\n\nThis struct comes in a 64bit version [MiePotential] and a 32bit variant\n[MiePotentialF32].\n\n# References\nG. Mie, \xe2\x80\x9cZur kinetischen Theorie der einatomigen K\xc3\xb6rper,\xe2\x80\x9d\nAnnalen der Physik, vol. 316, no. 8. Wiley, pp. 657\xe2\x80\x93697, Jan. 1903.\ndoi: [10.1002/andp.19033160802](https://doi.org/10.1002/andp.19033160802).\x00"
const RAW_DOC: &'static CStr = c"Generalizeation of the [BoundLennardJones] potential.\n\n\\\\begin{align}\n U(r) &= C\\epsilon\\left[ \\left(\\frac{\\sigma}{r}\\right)^n -\n \\left(\\frac{\\sigma}{r}\\right)^m\\right]\\\\\\\\\n C &= \\frac{n}{n-m}\\left(\\frac{n}{m}\\right)^{\\frac{n}{n-m}}\\\\\\\\\n V(r) &= \\min(U(r), \\beta)\\theta(r-\\zeta)\n\\\\end{align}\n\nThis struct comes in a 64bit version [MiePotential] and a 32bit variant\n[MiePotentialF32].\n\n# References\nG. Mie, \xe2\x80\x9cZur kinetischen Theorie der einatomigen K\xc3\xb6rper,\xe2\x80\x9d\nAnnalen der Physik, vol. 316, no. 8. Wiley, pp. 657\xe2\x80\x93697, Jan. 1903.\ndoi: [10.1002/andp.19033160802](https://doi.org/10.1002/andp.19033160802).\x00"
Sourceconst DOC: &'static CStr
const DOC: &'static CStr
text_signature if a constructor is defined. Read moreSourcetype ThreadChecker = SendablePyClass<MiePotential>
type ThreadChecker = SendablePyClass<MiePotential>
Sourcetype PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
type PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
Sourcetype BaseNativeType = PyAny
type BaseNativeType = PyAny
PyAny by default, and when you declare
#[pyclass(extends=PyDict)], it’s PyDict.fn items_iter() -> PyClassItemsIter
fn lazy_type_object() -> &'static LazyTypeObject<Self>
fn dict_offset() -> Option<isize>
fn weaklist_offset() -> Option<isize>
Sourceimpl PyClassNewTextSignature for MiePotential
impl PyClassNewTextSignature for MiePotential
const TEXT_SIGNATURE: &'static str = "(radius, strength, bound, cutoff, en, em)"
Sourceimpl PyMethods<MiePotential> for PyClassImplCollector<MiePotential>
impl PyMethods<MiePotential> for PyClassImplCollector<MiePotential>
fn py_methods(self) -> &'static PyClassItems
Sourceimpl PyTypeInfo for MiePotential
impl PyTypeInfo for MiePotential
Sourcefn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
fn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
fn is_type_of(object: &Bound<'_, PyAny>) -> bool
fn is_type_of(object: &Bound<'_, PyAny>) -> bool
object is an instance of this type or a subclass of this type.fn is_exact_type_of(object: &Bound<'_, PyAny>) -> bool
fn is_exact_type_of(object: &Bound<'_, PyAny>) -> bool
object is an instance of this type.Sourceimpl RelativeEq for MiePotential
impl RelativeEq for MiePotential
Sourcefn default_max_relative() -> Self::Epsilon
fn default_max_relative() -> Self::Epsilon
Sourcefn relative_eq(
&self,
other: &Self,
epsilon: Self::Epsilon,
max_relative: Self::Epsilon,
) -> bool
fn relative_eq( &self, other: &Self, epsilon: Self::Epsilon, max_relative: Self::Epsilon, ) -> bool
fn relative_ne(
&self,
other: &Rhs,
epsilon: Self::Epsilon,
max_relative: Self::Epsilon,
) -> bool
fn relative_ne( &self, other: &Rhs, epsilon: Self::Epsilon, max_relative: Self::Epsilon, ) -> bool
RelativeEq::relative_eq].Sourceimpl Serialize for MiePotential
impl Serialize for MiePotential
impl DerefToPyAny for MiePotential
impl ExtractPyClassWithClone for MiePotential
impl StructuralPartialEq for MiePotential