pub struct MiePotentialF32 {
pub radius: f32,
pub strength: f32,
pub bound: f32,
pub cutoff: f32,
pub en: f32,
pub em: f32,
}Expand description
Generalizeation of the BoundLennardJones potential.
\begin{align} U(r) &= C\epsilon\left[ \left(\frac{\sigma}{r}\right)^n - \left(\frac{\sigma}{r}\right)^m\right]\\ C &= \frac{n}{n-m}\left(\frac{n}{m}\right)^{\frac{n}{n-m}}\\ V(r) &= \min(U(r), \beta)\theta(r-\zeta) \end{align}
This struct comes in a 64bit version MiePotential and a 32bit variant MiePotentialF32.
References
G. Mie, “Zur kinetischen Theorie der einatomigen Körper,” Annalen der Physik, vol. 316, no. 8. Wiley, pp. 657–697, Jan. 1903. doi: 10.1002/andp.19033160802.
Fields
radius: f32Interaction strength $\epsilon$ of the potential.
strength: f32Overall size $\sigma$ of the object of the potential.
bound: f32Numerical bound $\beta$ of the interaction strength.
cutoff: f32Defines a cutoff $\zeta$ after which the potential will be fixed to exactly zero.
en: f32Exponent $n$ of the potential
em: f32Exponent $m$ of the potential
Implementations
Sourceimpl MiePotentialF32
impl MiePotentialF32
Sourcepub fn new(
radius: f32,
strength: f32,
bound: f32,
cutoff: f32,
en: f32,
em: f32,
) -> Self
Available on crate feature pyo3 only.
pub fn new( radius: f32, strength: f32, bound: f32, cutoff: f32, en: f32, em: f32, ) -> Self
pyo3 only.Constructs a new MiePotentialF32
use cellular_raza_building_blocks::MiePotentialF32;
let (radius, strength, bound, cutoff, en, em) = (1.0, 1.0, 1.0, 1.0, 1.0, 1.0);
let mie_potential = MiePotentialF32::new(
radius,
strength,
bound,
cutoff,
en,
em,
);Trait Implementations
Sourceimpl AbsDiffEq for MiePotentialF32
impl AbsDiffEq for MiePotentialF32
Sourcefn default_epsilon() -> Self::Epsilon
fn default_epsilon() -> Self::Epsilon
Sourcefn abs_diff_eq(&self, other: &Self, epsilon: Self::Epsilon) -> bool
fn abs_diff_eq(&self, other: &Self, epsilon: Self::Epsilon) -> bool
fn abs_diff_ne(&self, other: &Rhs, epsilon: Self::Epsilon) -> bool
fn abs_diff_ne(&self, other: &Rhs, epsilon: Self::Epsilon) -> bool
AbsDiffEq::abs_diff_eq].Sourceimpl Clone for MiePotentialF32
impl Clone for MiePotentialF32
Sourcefn clone(&self) -> MiePotentialF32
fn clone(&self) -> MiePotentialF32
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for MiePotentialF32
impl Debug for MiePotentialF32
Sourceimpl<'de> Deserialize<'de> for MiePotentialF32
impl<'de> Deserialize<'de> for MiePotentialF32
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Sourceimpl<const D: usize> Interaction<Matrix<f32, Const<D>, Const<1>, ArrayStorage<f32, D, 1>>, Matrix<f32, Const<D>, Const<1>, ArrayStorage<f32, D, 1>>, Matrix<f32, Const<D>, Const<1>, ArrayStorage<f32, D, 1>>, f32> for MiePotentialF32
impl<const D: usize> Interaction<Matrix<f32, Const<D>, Const<1>, ArrayStorage<f32, D, 1>>, Matrix<f32, Const<D>, Const<1>, ArrayStorage<f32, D, 1>>, Matrix<f32, Const<D>, Const<1>, ArrayStorage<f32, D, 1>>, f32> for MiePotentialF32
Sourcefn calculate_force_between(
&self,
own_pos: &SVector<f32, D>,
_own_vel: &SVector<f32, D>,
ext_pos: &SVector<f32, D>,
_ext_vel: &SVector<f32, D>,
ext_radius: &f32,
) -> Result<(SVector<f32, D>, SVector<f32, D>), CalcError>
fn calculate_force_between( &self, own_pos: &SVector<f32, D>, _own_vel: &SVector<f32, D>, ext_pos: &SVector<f32, D>, _ext_vel: &SVector<f32, D>, ext_radius: &f32, ) -> Result<(SVector<f32, D>, SVector<f32, D>), CalcError>
Sourceimpl InteractionInformation<f32> for MiePotentialF32
impl InteractionInformation<f32> for MiePotentialF32
Sourcefn get_interaction_information(&self) -> f32
fn get_interaction_information(&self) -> f32
Sourceimpl<'py> IntoPyObject<'py> for MiePotentialF32
impl<'py> IntoPyObject<'py> for MiePotentialF32
Sourcetype Target = MiePotentialF32
type Target = MiePotentialF32
Sourcetype Output = Bound<'py, <MiePotentialF32 as IntoPyObject<'py>>::Target>
type Output = Bound<'py, <MiePotentialF32 as IntoPyObject<'py>>::Target>
Sourcefn into_pyobject(
self,
py: Python<'py>,
) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
fn into_pyobject( self, py: Python<'py>, ) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
Sourceimpl PartialEq for MiePotentialF32
impl PartialEq for MiePotentialF32
Sourceimpl PyClass for MiePotentialF32
impl PyClass for MiePotentialF32
Sourceimpl PyClassImpl for MiePotentialF32
impl PyClassImpl for MiePotentialF32
Sourceconst IS_BASETYPE: bool = false
const IS_BASETYPE: bool = false
Sourceconst IS_SUBCLASS: bool = false
const IS_SUBCLASS: bool = false
Sourceconst IS_MAPPING: bool = false
const IS_MAPPING: bool = false
Sourceconst IS_SEQUENCE: bool = false
const IS_SEQUENCE: bool = false
Sourceconst IS_IMMUTABLE_TYPE: bool = false
const IS_IMMUTABLE_TYPE: bool = false
Sourceconst RAW_DOC: &'static CStr = c"Generalizeation of the [BoundLennardJones] potential.\n\n\\\\begin{align}\n U(r) &= C\\epsilon\\left[ \\left(\\frac{\\sigma}{r}\\right)^n -\n \\left(\\frac{\\sigma}{r}\\right)^m\\right]\\\\\\\\\n C &= \\frac{n}{n-m}\\left(\\frac{n}{m}\\right)^{\\frac{n}{n-m}}\\\\\\\\\n V(r) &= \\min(U(r), \\beta)\\theta(r-\\zeta)\n\\\\end{align}\n\nThis struct comes in a 64bit version [MiePotential] and a 32bit variant\n[MiePotentialF32].\n\n# References\nG. Mie, \xe2\x80\x9cZur kinetischen Theorie der einatomigen K\xc3\xb6rper,\xe2\x80\x9d\nAnnalen der Physik, vol. 316, no. 8. Wiley, pp. 657\xe2\x80\x93697, Jan. 1903.\ndoi: [10.1002/andp.19033160802](https://doi.org/10.1002/andp.19033160802).\x00"
const RAW_DOC: &'static CStr = c"Generalizeation of the [BoundLennardJones] potential.\n\n\\\\begin{align}\n U(r) &= C\\epsilon\\left[ \\left(\\frac{\\sigma}{r}\\right)^n -\n \\left(\\frac{\\sigma}{r}\\right)^m\\right]\\\\\\\\\n C &= \\frac{n}{n-m}\\left(\\frac{n}{m}\\right)^{\\frac{n}{n-m}}\\\\\\\\\n V(r) &= \\min(U(r), \\beta)\\theta(r-\\zeta)\n\\\\end{align}\n\nThis struct comes in a 64bit version [MiePotential] and a 32bit variant\n[MiePotentialF32].\n\n# References\nG. Mie, \xe2\x80\x9cZur kinetischen Theorie der einatomigen K\xc3\xb6rper,\xe2\x80\x9d\nAnnalen der Physik, vol. 316, no. 8. Wiley, pp. 657\xe2\x80\x93697, Jan. 1903.\ndoi: [10.1002/andp.19033160802](https://doi.org/10.1002/andp.19033160802).\x00"
Sourceconst DOC: &'static CStr
const DOC: &'static CStr
text_signature if a constructor is defined. Read moreSourcetype ThreadChecker = SendablePyClass<MiePotentialF32>
type ThreadChecker = SendablePyClass<MiePotentialF32>
Sourcetype PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
type PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
Sourcetype BaseNativeType = PyAny
type BaseNativeType = PyAny
PyAny by default, and when you declare
#[pyclass(extends=PyDict)], it’s PyDict.fn items_iter() -> PyClassItemsIter
fn lazy_type_object() -> &'static LazyTypeObject<Self>
fn dict_offset() -> Option<isize>
fn weaklist_offset() -> Option<isize>
Sourceimpl PyClassNewTextSignature for MiePotentialF32
impl PyClassNewTextSignature for MiePotentialF32
const TEXT_SIGNATURE: &'static str = "(radius, strength, bound, cutoff, en, em)"
Sourceimpl PyMethods<MiePotentialF32> for PyClassImplCollector<MiePotentialF32>
impl PyMethods<MiePotentialF32> for PyClassImplCollector<MiePotentialF32>
fn py_methods(self) -> &'static PyClassItems
Sourceimpl PyTypeInfo for MiePotentialF32
impl PyTypeInfo for MiePotentialF32
Sourcefn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
fn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
fn is_type_of(object: &Bound<'_, PyAny>) -> bool
fn is_type_of(object: &Bound<'_, PyAny>) -> bool
object is an instance of this type or a subclass of this type.fn is_exact_type_of(object: &Bound<'_, PyAny>) -> bool
fn is_exact_type_of(object: &Bound<'_, PyAny>) -> bool
object is an instance of this type.Sourceimpl RelativeEq for MiePotentialF32
impl RelativeEq for MiePotentialF32
Sourcefn default_max_relative() -> Self::Epsilon
fn default_max_relative() -> Self::Epsilon
Sourcefn relative_eq(
&self,
other: &Self,
epsilon: Self::Epsilon,
max_relative: Self::Epsilon,
) -> bool
fn relative_eq( &self, other: &Self, epsilon: Self::Epsilon, max_relative: Self::Epsilon, ) -> bool
fn relative_ne(
&self,
other: &Rhs,
epsilon: Self::Epsilon,
max_relative: Self::Epsilon,
) -> bool
fn relative_ne( &self, other: &Rhs, epsilon: Self::Epsilon, max_relative: Self::Epsilon, ) -> bool
RelativeEq::relative_eq].Sourceimpl Serialize for MiePotentialF32
impl Serialize for MiePotentialF32
impl DerefToPyAny for MiePotentialF32
impl ExtractPyClassWithClone for MiePotentialF32
impl StructuralPartialEq for MiePotentialF32