pub struct MorsePotential {
pub radius: f64,
pub potential_stiffness: f64,
pub cutoff: f64,
pub strength: f64,
}Expand description
Famous Morse potential for diatomic molecules.
Parameters & Variables
| Symbol | Struct Field | Description |
|---|---|---|
| $R$ | radius | Radius of the particle |
| $\lambda$ | potential_stiffness | Can be interpreted as the inverse width of the potential |
cutoff | Cutoff after which the interaction strength is identically 0 | |
| $V_0$ | strength | Interaction strength |
| $r$ | Distance between interacting particles |
\begin{equation} V(r) = V_0\left(1 - e^{-\lambda(r-R)}\right)^2 \end{equation}
References
[1] P. M. Morse, “Diatomic Molecules According to the Wave Mechanics. II. Vibrational Levels,” Physical Review, vol. 34, no. 1. American Physical Society (APS), pp. 57–64, Jul. 01, 1929. doi: 10.1103/physrev.34.57.
Fields
radius: f64Radius of the object
potential_stiffness: f64Defines the length for the interaction range
cutoff: f64Cutoff after which the interaction is exactly 0
strength: f64Strength of the interaction
Implementations
Sourceimpl MorsePotential
impl MorsePotential
Sourcepub fn new(
radius: f64,
potential_stiffness: f64,
cutoff: f64,
strength: f64,
) -> Self
Available on crate feature pyo3 only.
pub fn new( radius: f64, potential_stiffness: f64, cutoff: f64, strength: f64, ) -> Self
pyo3 only.Constructs a new MorsePotential
use cellular_raza_building_blocks::MorsePotential;
let morse_potential = MorsePotential::new(
radius,
potential_stiffness,
cutoff,
strength,
);Trait Implementations
Sourceimpl AbsDiffEq for MorsePotential
impl AbsDiffEq for MorsePotential
Sourcefn default_epsilon() -> Self::Epsilon
fn default_epsilon() -> Self::Epsilon
The default tolerance to use when testing values that are close together. Read more
Sourcefn abs_diff_eq(&self, other: &Self, epsilon: Self::Epsilon) -> bool
fn abs_diff_eq(&self, other: &Self, epsilon: Self::Epsilon) -> bool
A test for equality that uses the absolute difference to compute the approximimate
equality of two numbers.
fn abs_diff_ne(&self, other: &Rhs, epsilon: Self::Epsilon) -> bool
fn abs_diff_ne(&self, other: &Rhs, epsilon: Self::Epsilon) -> bool
The inverse of [
AbsDiffEq::abs_diff_eq].Sourceimpl Clone for MorsePotential
impl Clone for MorsePotential
Sourcefn clone(&self) -> MorsePotential
fn clone(&self) -> MorsePotential
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MorsePotential
impl Debug for MorsePotential
Sourceimpl<'de> Deserialize<'de> for MorsePotential
impl<'de> Deserialize<'de> for MorsePotential
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<const D: usize> Interaction<Matrix<f64, Const<D>, Const<1>, ArrayStorage<f64, D, 1>>, Matrix<f64, Const<D>, Const<1>, ArrayStorage<f64, D, 1>>, Matrix<f64, Const<D>, Const<1>, ArrayStorage<f64, D, 1>>, f64> for MorsePotential
impl<const D: usize> Interaction<Matrix<f64, Const<D>, Const<1>, ArrayStorage<f64, D, 1>>, Matrix<f64, Const<D>, Const<1>, ArrayStorage<f64, D, 1>>, Matrix<f64, Const<D>, Const<1>, ArrayStorage<f64, D, 1>>, f64> for MorsePotential
Sourcefn calculate_force_between(
&self,
own_pos: &SVector<f64, D>,
_own_vel: &SVector<f64, D>,
ext_pos: &SVector<f64, D>,
_ext_vel: &SVector<f64, D>,
ext_info: &f64,
) -> Result<(SVector<f64, D>, SVector<f64, D>), CalcError>
fn calculate_force_between( &self, own_pos: &SVector<f64, D>, _own_vel: &SVector<f64, D>, ext_pos: &SVector<f64, D>, _ext_vel: &SVector<f64, D>, ext_info: &f64, ) -> Result<(SVector<f64, D>, SVector<f64, D>), CalcError>
Calculates the forces (velocity-derivative) on the corresponding external position given
external velocity.
By providing velocities, we can calculate terms that are related to friction.
The function returns two forces, one acting on the current agent and the other on the
external agent.
Sourceimpl InteractionInformation<f64> for MorsePotential
impl InteractionInformation<f64> for MorsePotential
Sourcefn get_interaction_information(&self) -> f64
fn get_interaction_information(&self) -> f64
Get additional information of cellular properties (ie. for cell-specific interactions).
Sourceimpl<'py> IntoPyObject<'py> for MorsePotential
impl<'py> IntoPyObject<'py> for MorsePotential
Sourcetype Target = MorsePotential
type Target = MorsePotential
The Python output type
Sourcetype Output = Bound<'py, <MorsePotential as IntoPyObject<'py>>::Target>
type Output = Bound<'py, <MorsePotential as IntoPyObject<'py>>::Target>
The smart pointer type to use. Read more
Sourcefn into_pyobject(
self,
py: Python<'py>,
) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
fn into_pyobject( self, py: Python<'py>, ) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
Performs the conversion.
Sourceimpl PartialEq for MorsePotential
impl PartialEq for MorsePotential
Sourceimpl PyClass for MorsePotential
impl PyClass for MorsePotential
Sourceimpl PyClassImpl for MorsePotential
impl PyClassImpl for MorsePotential
Sourceconst IS_BASETYPE: bool = false
const IS_BASETYPE: bool = false
#[pyclass(subclass)]
Sourceconst IS_SUBCLASS: bool = false
const IS_SUBCLASS: bool = false
#[pyclass(extends=…)]
Sourceconst IS_MAPPING: bool = false
const IS_MAPPING: bool = false
#[pyclass(mapping)]
Sourceconst IS_SEQUENCE: bool = false
const IS_SEQUENCE: bool = false
#[pyclass(sequence)]
Sourceconst IS_IMMUTABLE_TYPE: bool = false
const IS_IMMUTABLE_TYPE: bool = false
#[pyclass(immutable_type)]
Sourceconst RAW_DOC: &'static CStr = c"Famous [Morse](https://doi.org/10.1103/PhysRev.34.57) potential for diatomic molecules.\n\n# Parameters & Variables\n| Symbol | Struct Field | Description |\n|:---:| --- | --- |\n| $R$ | `radius` | Radius of the particle |\n| $\\lambda$ | `potential_stiffness` | Can be interpreted as the inverse width of the potential |\n| | `cutoff` | Cutoff after which the interaction strength is identically 0 |\n| $V_0$ | `strength` | Interaction strength |\n| | | |\n| $r$ | | Distance between interacting particles |\n\n\\\\begin{equation}\n V(r) = V_0\\left(1 - e^{-\\lambda(r-R)}\\right)^2\n\\\\end{equation}\n\n\n# References\n\\[1\\]\nP. M. Morse,\n\xe2\x80\x9cDiatomic Molecules According to the Wave Mechanics. II. Vibrational Levels,\xe2\x80\x9d\nPhysical Review, vol. 34, no. 1. American Physical Society (APS),\npp. 57\xe2\x80\x9364, Jul. 01, 1929.\ndoi: [10.1103/physrev.34.57](https://doi.org/10.1103/PhysRev.34.57).\x00"
const RAW_DOC: &'static CStr = c"Famous [Morse](https://doi.org/10.1103/PhysRev.34.57) potential for diatomic molecules.\n\n# Parameters & Variables\n| Symbol | Struct Field | Description |\n|:---:| --- | --- |\n| $R$ | `radius` | Radius of the particle |\n| $\\lambda$ | `potential_stiffness` | Can be interpreted as the inverse width of the potential |\n| | `cutoff` | Cutoff after which the interaction strength is identically 0 |\n| $V_0$ | `strength` | Interaction strength |\n| | | |\n| $r$ | | Distance between interacting particles |\n\n\\\\begin{equation}\n V(r) = V_0\\left(1 - e^{-\\lambda(r-R)}\\right)^2\n\\\\end{equation}\n\n\n# References\n\\[1\\]\nP. M. Morse,\n\xe2\x80\x9cDiatomic Molecules According to the Wave Mechanics. II. Vibrational Levels,\xe2\x80\x9d\nPhysical Review, vol. 34, no. 1. American Physical Society (APS),\npp. 57\xe2\x80\x9364, Jul. 01, 1929.\ndoi: [10.1103/physrev.34.57](https://doi.org/10.1103/PhysRev.34.57).\x00"
Docstring for the class provided on the struct or enum. Read more
Sourceconst DOC: &'static CStr
const DOC: &'static CStr
Fully rendered class doc, including the
text_signature if a constructor is defined. Read moreSourcetype ThreadChecker = SendablePyClass<MorsePotential>
type ThreadChecker = SendablePyClass<MorsePotential>
This handles following two situations: Read more
Sourcetype PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
type PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
Immutable or mutable
Sourcetype BaseNativeType = PyAny
type BaseNativeType = PyAny
The closest native ancestor. This is
PyAny by default, and when you declare
#[pyclass(extends=PyDict)], it’s PyDict.fn items_iter() -> PyClassItemsIter
fn lazy_type_object() -> &'static LazyTypeObject<Self>
fn dict_offset() -> Option<isize>
fn weaklist_offset() -> Option<isize>
Sourceimpl PyClassNewTextSignature for MorsePotential
impl PyClassNewTextSignature for MorsePotential
const TEXT_SIGNATURE: &'static str = "(radius, potential_stiffness, cutoff, strength)"
Sourceimpl PyMethods<MorsePotential> for PyClassImplCollector<MorsePotential>
impl PyMethods<MorsePotential> for PyClassImplCollector<MorsePotential>
fn py_methods(self) -> &'static PyClassItems
Sourceimpl PyTypeInfo for MorsePotential
impl PyTypeInfo for MorsePotential
Sourcefn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
fn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
Returns the PyTypeObject instance for this type.
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
Returns the safe abstraction over the type object.
fn is_type_of(object: &Bound<'_, PyAny>) -> bool
fn is_type_of(object: &Bound<'_, PyAny>) -> bool
Checks if
object is an instance of this type or a subclass of this type.fn is_exact_type_of(object: &Bound<'_, PyAny>) -> bool
fn is_exact_type_of(object: &Bound<'_, PyAny>) -> bool
Checks if
object is an instance of this type.Sourceimpl RelativeEq for MorsePotential
impl RelativeEq for MorsePotential
Sourcefn default_max_relative() -> Self::Epsilon
fn default_max_relative() -> Self::Epsilon
The default relative tolerance for testing values that are far-apart. Read more
Sourcefn relative_eq(
&self,
other: &Self,
epsilon: Self::Epsilon,
max_relative: Self::Epsilon,
) -> bool
fn relative_eq( &self, other: &Self, epsilon: Self::Epsilon, max_relative: Self::Epsilon, ) -> bool
A test for equality that uses a relative comparison if the values are far apart.
fn relative_ne(
&self,
other: &Rhs,
epsilon: Self::Epsilon,
max_relative: Self::Epsilon,
) -> bool
fn relative_ne( &self, other: &Rhs, epsilon: Self::Epsilon, max_relative: Self::Epsilon, ) -> bool
The inverse of [
RelativeEq::relative_eq].Sourceimpl Serialize for MorsePotential
impl Serialize for MorsePotential
impl DerefToPyAny for MorsePotential
impl ExtractPyClassWithClone for MorsePotential
impl StructuralPartialEq for MorsePotential