pub struct NewtonDamped2DF32 {
pub pos: SVector<f32, 2>,
pub vel: SVector<f32, 2>,
pub damping_constant: f32,
pub mass: f32,
}Expand description
Newtonian dynamics governed by mass and damping.
Parameters
| Symbol | Parameter | Description |
|---|---|---|
| $\vec{x}$ | pos | Position of the particle. |
| $\dot{\vec{x}}$ | vel | Velocity of the particle. |
| $\lambda$ | damping | Damping constant |
| $m$ | mass | Mass of the particle. |
Equations
The equation of motion is given by \begin{equation} m \ddot{\vec{x}} = \vec{F} - \lambda \dot{\vec{x}} \end{equation} where $\vec{F}$ is the force as calculated by the Interaction trait.
Comments
If the cell is growing, we need to increase the mass $m$. By interacting with the outside world, we can adapt $\lambda$ to external values although this is rarely desirable. Both operations need to be implemented by other concepts such as Cycle.
Fields
pos: SVector<f32, 2>Current position $\vec{x}$ given by a vector of dimension D.
vel: SVector<f32, 2>Current velocity $\dot{\vec{x}}$ given by a vector of dimension D.
damping_constant: f32Damping constant $\lambda$.
mass: f32Mass $m$ of the object.
Implementations
Sourceimpl NewtonDamped2DF32
impl NewtonDamped2DF32
Sourcepub fn get_damping_constant(&self) -> f32
Available on crate feature pyo3 only.
pub fn get_damping_constant(&self) -> f32
pyo3 only.[pyo3] getter for damping_constant
Sourcepub fn set_pos(&mut self, pos: [f32; 2])
Available on crate feature pyo3 only.
pub fn set_pos(&mut self, pos: [f32; 2])
pyo3 only.[pyo3] setter for pos
Sourcepub fn set_vel(&mut self, vel: [f32; 2])
Available on crate feature pyo3 only.
pub fn set_vel(&mut self, vel: [f32; 2])
pyo3 only.[pyo3] setter for vel
Sourcepub fn set_damping_constant(&mut self, damping_constant: f32)
Available on crate feature pyo3 only.
pub fn set_damping_constant(&mut self, damping_constant: f32)
pyo3 only.[pyo3] setter for damping_constant