pub struct RodInteraction<I>(pub I);Expand description
Automatically derives a [Interaction] suitable for rods from a point-wise interaction.
Tuple Fields
0: ITrait Implementations
Sourceimpl<I> AbsDiffEq for RodInteraction<I>
impl<I> AbsDiffEq for RodInteraction<I>
Sourcefn default_epsilon() -> Self::Epsilon
fn default_epsilon() -> Self::Epsilon
The default tolerance to use when testing values that are close together. Read more
Sourcefn abs_diff_eq(&self, other: &Self, epsilon: Self::Epsilon) -> bool
fn abs_diff_eq(&self, other: &Self, epsilon: Self::Epsilon) -> bool
A test for equality that uses the absolute difference to compute the approximimate
equality of two numbers.
fn abs_diff_ne(&self, other: &Rhs, epsilon: Self::Epsilon) -> bool
fn abs_diff_ne(&self, other: &Rhs, epsilon: Self::Epsilon) -> bool
The inverse of [
AbsDiffEq::abs_diff_eq].Sourceimpl<I: Clone> Clone for RodInteraction<I>
impl<I: Clone> Clone for RodInteraction<I>
Sourcefn clone(&self) -> RodInteraction<I>
fn clone(&self) -> RodInteraction<I>
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<I: Debug> Debug for RodInteraction<I>
impl<I: Debug> Debug for RodInteraction<I>
Sourceimpl<'de, I> Deserialize<'de> for RodInteraction<I>where
I: Deserialize<'de>,
impl<'de, I> Deserialize<'de> for RodInteraction<I>where
I: Deserialize<'de>,
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<I, F, Inf, const D: usize> Interaction<Matrix<F, Dyn, Const<D>, VecStorage<F, Dyn, Const<D>>>, Matrix<F, Dyn, Const<D>, VecStorage<F, Dyn, Const<D>>>, Matrix<F, Dyn, Const<D>, VecStorage<F, Dyn, Const<D>>>, Inf> for RodInteraction<I>
impl<I, F, Inf, const D: usize> Interaction<Matrix<F, Dyn, Const<D>, VecStorage<F, Dyn, Const<D>>>, Matrix<F, Dyn, Const<D>, VecStorage<F, Dyn, Const<D>>>, Matrix<F, Dyn, Const<D>, VecStorage<F, Dyn, Const<D>>>, Inf> for RodInteraction<I>
Sourcefn calculate_force_between(
&self,
own_pos: &Matrix<F, Dyn, Const<D>, VecStorage<F, Dyn, Const<D>>>,
own_vel: &Matrix<F, Dyn, Const<D>, VecStorage<F, Dyn, Const<D>>>,
ext_pos: &Matrix<F, Dyn, Const<D>, VecStorage<F, Dyn, Const<D>>>,
ext_vel: &Matrix<F, Dyn, Const<D>, VecStorage<F, Dyn, Const<D>>>,
ext_inf: &Inf,
) -> Result<(Matrix<F, Dyn, Const<D>, VecStorage<F, Dyn, Const<D>>>, Matrix<F, Dyn, Const<D>, VecStorage<F, Dyn, Const<D>>>), CalcError>
fn calculate_force_between( &self, own_pos: &Matrix<F, Dyn, Const<D>, VecStorage<F, Dyn, Const<D>>>, own_vel: &Matrix<F, Dyn, Const<D>, VecStorage<F, Dyn, Const<D>>>, ext_pos: &Matrix<F, Dyn, Const<D>, VecStorage<F, Dyn, Const<D>>>, ext_vel: &Matrix<F, Dyn, Const<D>, VecStorage<F, Dyn, Const<D>>>, ext_inf: &Inf, ) -> Result<(Matrix<F, Dyn, Const<D>, VecStorage<F, Dyn, Const<D>>>, Matrix<F, Dyn, Const<D>, VecStorage<F, Dyn, Const<D>>>), CalcError>
Calculates the forces (velocity-derivative) on the corresponding external position given
external velocity.
By providing velocities, we can calculate terms that are related to friction.
The function returns two forces, one acting on the current agent and the other on the
external agent.
Sourceimpl<I, Inf> InteractionInformation<Inf> for RodInteraction<I>where
I: InteractionInformation<Inf>,
impl<I, Inf> InteractionInformation<Inf> for RodInteraction<I>where
I: InteractionInformation<Inf>,
Sourcefn get_interaction_information(&self) -> Inf
fn get_interaction_information(&self) -> Inf
Get additional information of cellular properties (ie. for cell-specific interactions).
Sourceimpl<I: PartialEq> PartialEq for RodInteraction<I>
impl<I: PartialEq> PartialEq for RodInteraction<I>
Sourceimpl<I> Serialize for RodInteraction<I>where
I: Serialize,
impl<I> Serialize for RodInteraction<I>where
I: Serialize,
impl<I> StructuralPartialEq for RodInteraction<I>