pub struct VertexDerivedInteraction<A, R, I1 = (), I2 = ()> {
pub outside_interaction: A,
pub inside_interaction: R,
/* private fields */
}Expand description
Derives an interaction potential from a point-like potential.
Fields
outside_interaction: AInteraction potential used when other vertex is outside of current polygon.
inside_interaction: RInteraction potential when vertex is inside current polygon.
Implementations
Sourceimpl<A, R, I1, I2> VertexDerivedInteraction<A, R, I1, I2>
impl<A, R, I1, I2> VertexDerivedInteraction<A, R, I1, I2>
Sourcepub fn from_two_forces(attracting_force: A, repelling_force: R) -> Self
pub fn from_two_forces(attracting_force: A, repelling_force: R) -> Self
Constructs a new VertexDerivedInteraction from two Interaction potentials.
One serves as the inside and one for the outside interaction.